<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// C
	'compresseur_description' => 'Kompression von CSS und Javascript-Code im Kopf der Seiten unter <code>ecrire/</code> und/oder auf der öffentlichen Website',
	'compresseur_slogan' => 'Kompression von CSS und Javascript-Code',
];
